==> pierogi_1.1.46.tar.gz: pierogi-1.1.46/keysets/kenwood.h <==
//
// kenwood.h
//
// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef KENWOOD_H
#define KENWOOD_H

#include "pirkeysetmetadata.h"

class QComboBox;

class KenwoodAudio1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodAudio1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class KenwoodComponent1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodComponent1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class KenwoodComponent2: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodComponent2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class KenwoodComponent3: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodComponent3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

class KenwoodCD1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodCD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class KenwoodDVD1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class KenwoodTV1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb);
};

#endif // KENWOOD_H

==> pierogi_1.1.47.tar.gz: pierogi-1.1.47/keysets/kenwood.h <==
//
// kenwood.h
//
// Copyright 2012 - 2015 by John Pietrzak (jpietrzak8@gmail.com)
//
// This file is part of Pierogi.
//
// Pierogi is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// Pierogi is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation,
// Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
//

#ifndef KENWOOD_H
#define KENWOOD_H

#include "pirkeysetmetadata.h"

class QComboBox;

class KenwoodAudio1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodAudio1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

class KenwoodComponent1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodComponent1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

class KenwoodComponent2: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodComponent2(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

class KenwoodComponent3: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodComponent3(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

class KenwoodCD1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodCD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class KenwoodDVD1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodDVD1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);
};

class KenwoodTV1: public PIRKeysetMetaData
{
  Q_OBJECT

public:
  KenwoodTV1(
    unsigned int index);

  virtual void populateProtocol(
    QObject *guiObject);

  virtual void populateInputList(
    QComboBox *cb) const;
};

#endif // KENWOOD_H
